pub fn on_frame_image_ready(
child: impl IntoUiNode,
handler: Handler<FrameImageReadyArgs>,
) -> UiNodeExpand description
P On window frame rendered.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.