on_pre_frame_image_ready

Function on_pre_frame_image_ready 

pub fn on_pre_frame_image_ready(
    child: impl IntoUiNode,
    handler: Handler<FrameImageReadyArgs>,
) -> UiNode
P On window frame rendered.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.