pub fn on_pre_window_close(
child: impl IntoUiNode,
handler: Handler<WindowCloseArgs>,
) -> UiNodeExpand description
P On window closed.
See WINDOW_CLOSE_EVENT for more details of when this event notifies.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.