on_pre_window_exited_fullscreen

Function on_pre_window_exited_fullscreen 

pub fn on_pre_window_exited_fullscreen(
    child: impl IntoUiNode,
    handler: Handler<WindowChangedArgs>,
) -> UiNode
P On window state changed from WindowState::is_fullscreen.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.