on_pre_window_fullscreen

Function on_pre_window_fullscreen 

pub fn on_pre_window_fullscreen(
    child: impl IntoUiNode,
    handler: Handler<WindowChangedArgs>,
) -> UiNode
P On window state changed to WindowState::is_fullscreen.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.