pub fn on_pre_window_moved( child: impl IntoUiNode, handler: Handler<WindowChangedArgs>, ) -> UiNode
P On window position changed.
P
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.
handler
$pn_ident