on_pre_window_open

Function on_pre_window_open 

pub fn on_pre_window_open(
    child: impl IntoUiNode,
    handler: Handler<WindowOpenArgs>,
) -> UiNode
P On window opened.

This event notifies once per window, after the window content is inited.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.