on_pre_window_resized

Function on_pre_window_resized 

pub fn on_pre_window_resized(
    child: impl IntoUiNode,
    handler: Handler<WindowChangedArgs>,
) -> UiNode
P On window size changed.

Route

This event property uses the preview route, that is, the handler is called before the children widget handlers and before the $pn_ident handlers.