on_window_close

Function on_window_close 

pub fn on_window_close(
    child: impl IntoUiNode,
    handler: Handler<WindowCloseArgs>,
) -> UiNode
P On window closed.

See WINDOW_CLOSE_EVENT for more details of when this event notifies.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.