on_window_close_requested

Function on_window_close_requested 

pub fn on_window_close_requested(
    child: impl IntoUiNode,
    handler: Handler<WindowCloseRequestedArgs>,
) -> UiNode
P On window close requested.

Calling propagation().stop() on this event cancels the window close.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.