on_window_maximized

Function on_window_maximized 

pub fn on_window_maximized(
    child: impl IntoUiNode,
    handler: Handler<WindowChangedArgs>,
) -> UiNode
P On window state changed to WindowState::Maximized.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.