on_window_open

Function on_window_open 

pub fn on_window_open(
    child: impl IntoUiNode,
    handler: Handler<WindowOpenArgs>,
) -> UiNode
P On window opened.

This event notifies once per window, after the window content is inited.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.