pub fn on_window_unmaximized(
child: impl IntoUiNode,
handler: Handler<WindowChangedArgs>,
) -> UiNodeExpand description
P On window state changed from WindowState::Maximized.
Route
This event property uses the normal route, that is, the handler is called after the children widget handlers and after the
$pn_pre_ident
handlers.