Function on_pre_ime
Source pub fn on_pre_ime(child: impl IntoUiNode, handler: Handler<ImeArgs>) -> UiNode
P On Input Method Editor event.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.