pub fn on_pre_window_load(
child: impl IntoUiNode,
handler: Handler<WindowOpenArgs>,
) -> UiNodeExpand description
P On window loaded.
This event notifies once per window, after the first layout and all WindowLoadingHandle
have expired or dropped.
Route
This event property uses the preview route, that is, the handler is called before the children widget handlers and before the
$pn_ident
handlers.