on_window_load

Function on_window_load 

pub fn on_window_load(
    child: impl IntoUiNode,
    handler: Handler<WindowOpenArgs>,
) -> UiNode
P On window loaded.

This event notifies once per window, after the first layout and all WindowLoadingHandle have expired or dropped.

Route

This event property uses the normal route, that is, the handler is called after the children widget handlers and after the $pn_pre_ident handlers.