pub fn cache_shaders(
wgt: &mut WidgetBuilding,
enabled: impl IntoValue<Option<bool>>,
)Expand description
B Compiled shader cache overwrite for this window, if set to None the WINDOWS.default_cache_shaders is used.
Mixin Property
This property is a mixin, it modifies the widget builder during build, it does not produce a standalone UI node.