pub fn needs_fallback_chrome(
child: impl IntoUiNode,
needs: impl IntoVar<bool>,
) -> UiNodeExpand description
P Gets if a custom window chrome must be rendered.
This is true when is running in a desktop OS and chrome is true and state is not fullscreen and
WINDOWS.system_chrome is false.